<?php

namespace Modules\Parametros\Services;

use \Zeedhi\Framework\DB\StoredProcedure\StoredProcedure;
use \Zeedhi\Framework\DB\StoredProcedure\Param;

class sup03500ParametrizacaoProdutosSuprimentosService
{
    protected $connection;
    
    public function __construct($conection, $environment)
    {
        $this->connection = $conection;
        $this->environment = $environment;
    }
    
    /********************
     *      SELECTS     *
     * ******************/
    
    public function selectCdgrupprod()
    {
        $param = [ 
            "P_CDFILIALLOGADA" => $this->environment->getCdFilial(),
        ];
        
        $query = "SELECT
                    PARASUPRI.CDGRUPPROD
                FROM
                    FILIAL,
                    PARASUPRI
                WHERE
                    FILIAL.CDFILIAL = :P_CDFILIALLOGADA
                    AND PARASUPRI.CDFILIAL = NVL(FILIAL.CDFILCENTCMP, FILIAL.CDFILIAL)";
        try {
            $std = $this->connection->prepare($query);
            $std->execute($param);
            return $std->fetchAll();
        } catch (Exception $e) {
            throw $e;
        }
    }
    
    public function getCentralCompras()
    {
        $param = [ 
            ":P_CDFILIALLOGADA" => $this->environment->getCdFilial(),
        ];
        
        $query = "SELECT
                    NVL(CDFILCENTCMP, CDFILIAL) CDFILCENTCMP
                FROM
                    FILIAL
                WHERE
                    CDFILIAL = :P_CDFILIALLOGADA";
        try {
            $std = $this->connection->prepare($query);
            $std->execute($param);
            return $std->fetchAll();
        } catch (Exception $e) {
            throw $e;
        }
    }
    
    public function getParametrosParasupri($cdfilcentcmp)
    {
        $param = [ 
            ":P_CDFILCENTCMP" => $cdfilcentcmp,
        ];
        
        $query = "SELECT
                    CDGRUPPROD,
                    CDSUBGRARVOR
                FROM
                    PARASUPRI
                WHERE
                    CDFILIAL = :P_CDFILCENTCMP";
        try {
            $std = $this->connection->prepare($query);
            $std->execute($param);
            return $std->fetchAll();
        } catch (Exception $e) {
            throw $e;
        }
    }
    
    /********************
     *      PROCEDURE     *
     * ******************/
    
    public function procedureExcInc($row)
    {
        $connection = $this->connection;
        $procedure = new StoredProcedure($connection, 'GRAVA_PARAMPRODSUP');
        $procedure->addParam(new Param('P_OPERACAO',        Param::PARAM_INPUT, $row['OPERACAO'],           Param::PARAM_TYPE_STR));
        $procedure->addParam(new Param('P_NRSEQPARPROD',    Param::PARAM_INPUT, null,                       Param::PARAM_TYPE_STR));
        $procedure->addParam(new Param('P_CDFILIAL',        Param::PARAM_INPUT, $row['CDFILIAL'],           Param::PARAM_TYPE_STR));
        $procedure->addParam(new Param('P_CDPRODINI',       Param::PARAM_INPUT, $row['CDPRODINI'],          Param::PARAM_TYPE_STR));
        $procedure->addParam(new Param('P_CDPRODFIN',       Param::PARAM_INPUT, $row['CDPRODFIN'],          Param::PARAM_TYPE_STR));
        $procedure->addParam(new Param('P_CDPRODUTO',       Param::PARAM_INPUT, null,                       Param::PARAM_TYPE_STR));
        $procedure->addParam(new Param('P_CDFORNECED',      Param::PARAM_INPUT, null,                       Param::PARAM_TYPE_STR));
        $procedure->addParam(new Param('P_CDFILICTRL',      Param::PARAM_INPUT, null,                       Param::PARAM_TYPE_STR));
        $procedure->addParam(new Param('P_CDFILIOPELOG',    Param::PARAM_INPUT, $row['CDFILIOPELOG'],       Param::PARAM_TYPE_STR));
        $procedure->addParam(new Param('P_IDFILINEGREG',    Param::PARAM_INPUT, null,                       Param::PARAM_TYPE_STR));
        $procedure->addParam(new Param('P_IDFILINEGCOR',    Param::PARAM_INPUT, null,                       Param::PARAM_TYPE_STR));
        $procedure->addParam(new Param('P_IDPRODWEB',       Param::PARAM_INPUT, null,                       Param::PARAM_TYPE_STR));
        $procedure->addParam(new Param('P_NRCOLEPRECO',     Param::PARAM_INPUT, null,                       Param::PARAM_TYPE_STR));
        $procedure->addParam(new Param('P_CDFILCOLETA',     Param::PARAM_INPUT, null,                       Param::PARAM_TYPE_STR));
        $procedure->addParam(new Param('P_CDREGIAO',        Param::PARAM_INPUT, $row['CDREGIAO'],           Param::PARAM_TYPE_STR));
        $procedure->addParam(new Param('P_CDGRUPPROD',      Param::PARAM_INPUT, $row['CDGRUPPROD'],         Param::PARAM_TYPE_STR));
        $procedure->addParam(new Param('P_CDSUBGRPROD',     Param::PARAM_INPUT, $row['CDSUBGRPROD'],        Param::PARAM_TYPE_STR));
        $procedure->addParam(new Param('P_CDFILISUBGR',     Param::PARAM_INPUT, $row['CDFILISUBGR'],        Param::PARAM_TYPE_STR));
        $procedure->addParam(new Param('P_IDACORDOFORN',    Param::PARAM_INPUT, null,                       Param::PARAM_TYPE_STR));
        $procedure->addParam(new Param('P_CDFILCOTA',       Param::PARAM_INPUT, null,                       Param::PARAM_TYPE_STR));
        $procedure->addParam(new Param('P_IDOPERLOG',       Param::PARAM_INPUT, $row['IDOPERLOG'],          Param::PARAM_TYPE_STR));
        $procedure->addParam(new Param('P_RESULTADO',       Param::PARAM_OUTPUT, null,                      Param::PARAM_TYPE_STR, 10));
        
        
        return $procedure->execute();
    }
    
}